#!/usr/bin/python
# -*- coding: utf-8 -*-


import Image, urllib, os, sys, re


#==================================================================== CONF ====
#Base path for cover thumbnailer's pictures
BASE_PATH = '/usr/share/cover-thumbnailer/'

#Cover files list
COVER_FILES = ['cover.png', 'cover.jpg', '.cover.png', '.cover.jpg',
		'Cover.png', 'Cover.jpg', '.Cover.png', '.Cover.jpg',
		'folder.png', 'folder.jpg', '.folder.png', '.folder.jpg',
		'Folder.png', 'Folder.jpg', '.Folder.png', '.Folder.jpg']

#Supported picture ext (ALWAY LAST 4 CHARS !!)
PICTURES_EXT = ['.jpg', '.JPG', 'jpeg', 'JPEG',
		'.png', '.PNG',
		'.gif', '.GIF',
		'.bmp', '.BMP', #Window ans OS/2 bitmap
		'.ico', '.ICO', #Windows icon format
		'.tga', '.TGA', #Truevision Targa format
		'.tif', '.TIF', 'tiff', 'TIFF', #Adobe Tagged Image File Format
		'.psd', '.PSD', #Adobe Photosop format (only version 2.5 and 3.0)
		]

#==============================================================================


class Conf(object):
	'''
	Import configuration from config files.
	'''
	def __init__(self):
		#music
		self.music_paths = []
		self.music_default = BASE_PATH + 'music_default.png'
		self.music_fg = BASE_PATH + 'music_fg.png'
		self.music_bg = BASE_PATH + 'music_bg.png'
		#pictures
		self.pictures_paths = []
		self.pictures_default = BASE_PATH + 'pictures_default.png'
		self.pictures_fg = BASE_PATH + 'pictures_fg.png'
		self.pictures_bg = BASE_PATH + 'pictures_bg.png'
		#other
		self.other_fg = BASE_PATH + 'other_fg.png'
		#ignored
		self.ignored_paths = ['/tmp']
		self.ignored_dotted = False
		#global
		self.user_homedir = os.environ.get('HOME')
		self.user_gnomeconf = self.user_homedir + '/.config/user-dirs.dirs'
		self.user_conf = self.user_homedir + '/.cover-thumbnailer/cover-thumbnailer.conf'

		#get conf
		self.import_gnome_conf()
		self.import_user_conf()
		self.get_pictures_path()

	def import_gnome_conf(self):
		'''
		Import user folders from GNOME config file.
		'''
		if os.path.isfile(self.user_gnomeconf):
			file = open(self.user_gnomeconf, 'r')
			for line in file:
				if re.match(r'.*?XDG_MUSIC_DIR.*?=.*?"(.*)".*?', line):
					self.music_paths.append(re.match(r'.*?XDG_MUSIC_DIR.*?=.*?"(.*)".*?', line).group(1).replace('$HOME', self.user_homedir))
				elif re.match(r'.*?XDG_PICTURES_DIR.*?=.*?"(.*)".*?', line):
					self.pictures_paths.append(re.match(r'.*?XDG_PICTURES_DIR.*?=.*?"(.*)".*?', line).group(1).replace('$HOME', self.user_homedir))
			file.close()
		else:
			print "W: ["+__file__+":get_music_path] Can't find `user-dirs.dirs' file."
	
	def import_user_conf(self):
		'''
		Import user configuration file.
		'''
		if os.path.isfile(self.user_conf):
			current_section = None
			file = open(self.user_conf, 'r')
			#Read config
			for line in file:
				line = line.replace('\n', '')
				if re.match(r'\s?#.*', line):
					continue
				elif re.match(r'\s*\[music\]\s*', line.lower()):    #[music]
					current_section = 'music'
				elif re.match(r'\s*\[pictures\]\s*', line.lower()): #[pictures]
					current_section = 'pictures'
				elif re.match(r'\s*\[ignored\]\s*', line.lower()):  #[ignored]
					current_section = 'ignored'
				elif re.match(r'\s*(path|PATH)\s*=\s*"(.*)"\s*', line): #path=
					if current_section == 'music':
						self.music_paths.append(re.match(r'\s*(path|PATH)\s*=\s*"(.*)"\s*', line).group(2))
					elif current_section == 'pictures':
						self.pictures_paths.append(re.match(r'\s*(path|PATH)\s*=\s*"(.*)"\s*', line).group(2))
					elif current_section == 'ignored':
						self.ignored_paths.append(re.match(r'\s*(path|PATH)\s*=\s*"(.*)"\s*', line).group(2))
				elif re.match(r'\s*dotted\s*=\s*(yes|no|true|false|1|0)\s*', line.lower()): #doted=
					if current_section == 'ignored':
						value = re.match(r'\s*dotted\s*=\s*(yes|no|true|false|1|0)\s*', line.lower()).group(1)
						if value in ['yes', 'true', '1']:
							self.ignored_dotted = True
						elif value in ['no', 'false', '0']:
							self.ignored_dotted = False
			file.close()

			#Replace all ~ by user home dir
			for i in range(0, len(self.music_paths)):
				if self.music_paths[i][0] == '~':
					self.music_paths[i] = self.user_homedir+self.music_paths[i][1:]
			for i in range(0, len(self.pictures_paths)):
				if self.pictures_paths[i][0] == '~':
					self.pictures_paths[i] = self.user_homedir+self.pictures_paths[i][1:]
			for i in range(0, len(self.ignored_paths)):
				if self.ignored_paths[i][0] == '~':
					self.ignored_paths[i] = self.user_homedir+self.ignored_paths[i][1:]
		
	def get_pictures_path(self):
		'''
		Search if user have put some custom pictures in his home.
		'''
		#Music
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/music_default.png'):
			self.music_default = self.user_homedir + '/.cover-thumbnailer/music_default.png'
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/music_fg.png'):
			self.music_fg = self.user_homedir + '/.cover-thumbnailer/music_fg.png'
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/music_bg.png'):
			self.music_bg = self.user_homedir + '/.cover-thumbnailer/music_bg.png'
		#Pictures
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/pictures_default.png'):
			self.pictures_default = self.user_homedir + '/.cover-thumbnailer/pictures_default.png'
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/pictures_fg.png'):
			self.pictures_fg = self.user_homedir + '/.cover-thumbnailer/pictures_fg.png'
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/pictures_bg.png'):
			self.pictures_bg = self.user_homedir + '/.cover-thumbnailer/pictures_bg.png'
		#other
		if os.path.isfile(self.user_homedir + '/.cover-thumbnailer/other_fg.png'):
			self.other_fg = self.user_homedir + '/.cover-thumbnailer/other_fg.png'


conf = Conf()
#music
print "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ MUSIC ~~~~"
print conf.music_paths
print conf.music_default
print conf.music_fg
print conf.music_bg
#pictures
print "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ PICTS ~~~~"
print conf.pictures_paths
print conf.pictures_default
print conf.pictures_fg
print conf.pictures_bg
#other
print "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ OTHER ~~~~"
print conf.other_fg
#ignored
print "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ IGNOR ~~~~"
print conf.ignored_paths
print conf.ignored_dotted
#global
print "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ GLOBA ~~~~"
print conf.user_homedir
print conf.user_gnomeconf
print conf.user_conf


